<?php

namespace App\Http\Controllers\Admin;

use App\Category;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Prologue\Alerts\Facades\Alert;

class CategoriesController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('role:admin');
    }

    public function index()
    {
        $data['title'] = "Drug Categories";
        $data['categories'] = Category::paginate(30);
        return view('backpack::base.categories.index', $data)->render();
    }

    public function addNewCategory(Request $request)
    {
        $this->validate($request, [
            'category_name' => 'required|string|max:255']);

        $category = new Category;
        $category->name = $request->category_name;
        $category->slug = str_slug($category->name, $separator = '-');
        $category->description = $request->category_description;
        $category->save();
        Alert::success('New Category Added')->flash();
        return back();
    }

    public function delete($slug)
    {
        $category = Category::where('slug', $slug)->first();
        $category->delete();
        Alert::info('Category Deleted Successfully!')->flash();
        return back();
    }

    public function edit($slug)
    {
        $data['title'] = "Edit Category";
        $data['category'] = Category::where('slug', $slug)->first();
        return view('backpack::base.categories.edit', $data)->render();
    }

    public function update(Request $request, $slug)
    {
        $category = Category::where('slug', $slug)->first();
        $category->name = $request->name;
        $category->slug = str_slug($category->name, $separator = '-');
        $category->description = $request->description;
        $category->save();
        Alert::success('Category updated!')->flash();
        return redirect()->route('showAllCategories');
    }
}
