<?php

namespace App\Http\Controllers\Admin;

use App\Coupon;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Prologue\Alerts\Facades\Alert;

class CouponController extends Controller
{
    /**
     * constructor
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('role:admin');
    }

    /**
     * show all coupons
     *
     * @return void
     */
    public function index()
    {
        $title = 'Coupons';
        $coupons = Coupon::paginate(30);

        return view('backpack::base.coupons.index', compact('title', 'coupons'));
    }

    /**
     * add a new coupon
     *
     * @return \App\Coupon
     */
    public function create(Request $request)
    {
        $coupon = new Coupon;
        $coupon->code = strtoupper(request('coupon_code'));
        $coupon->rate = strtoupper(request('coupon_rate'));
        $coupon->save();

        Alert::success('Coupon has been created.')->flash();
        return redirect()->back();
    }

    /**
     * delete a coupon
     * @param App\Coupon
     * @return void
     */
    public function delete(Request $request, Coupon $coupon)
    {
        $coupon->delete();

        Alert::info('Coupon was deleted.')->flash();
        return redirect()->back();
    }
}
