<?php

namespace App\Http\Controllers\Admin;

use App\Company;
use App\Http\Controllers\Controller;
use App\Order;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;
use Prologue\Alerts\Facades\Alert;

class HomeController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('role:admin');
    }

    public function index()
    {
        return view('backpack::base.dashboard');
    }

    public function companies()
    {
        $data['companies'] = Company::all();
        $data['title'] = "Registered Companies";
        return view('backpack::base.companies', $data)->render();
    }

    public function editCompany($id)
    {
        $company = Company::findOrFail($id);
        $data['title'] = "Edit {$company->company_name} Data";
        $data['company'] = $company;
        return view('backpack::base.editcompany', $data);
    }

    public function updateCompanyData(Request $request, $id)
    {
        $company = Company::findOrFail($id);
        $company->company_name = Input::get('company_name');
        $company->street_address = Input::get('street_address');
        $company->city = Input::get('city');
        $company->state = Input::get('state');
        $company->country = Input::get('country');
        $company->delivery_info = Input::get('delivery_info');
        $company->save();
        Alert::success("{$company->company_name} data updated successfully!")->flash();
        return redirect()->route('companies');
    }

    public function orders()
    {
        $data['title'] = 'Manage Orders';
        $data['orders'] = Order::orderBy('created_at', 'desc')->paginate(30);
        return view('backpack::base.orders.index', $data);
    }

    public function viewOrderDetails($orderID)
    {
        $order = Order::where('id', $orderID)->first();
        $order_items = $order->orderitems;

        $data['order'] = $order;
        $data['order_items'] = $order_items;
        $data['title'] = "Order {$order->id}";

        return view('backpack::base.orders.order', $data);
    }
}
