<?php

namespace App\Http\Controllers\Admin;

use App\Category;
use App\Company;
use App\Http\Controllers\Controller;
use App\Stock;
use Illuminate\Http\Request;
use Prologue\Alerts\Facades\Alert;

class StockController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('role:admin');
    }

    public function showAllDrugs()
    {
        $data = [];
        $data['title'] = "Drugs Repository";
        $data['drugs'] = Stock::all();
        $data['pharmacies'] = Company::all();
        $data['categories'] = Category::all();

        return view('backpack::base.drugs.index', $data);
    }

    public function addNewDrug(Request $request)
    {
        $drug = new Stock;

        $company = Company::find($request->input('pharmacy'));

        if (!is_null($request->drug_image)) {
            $company_slug = str_slug($company->company_name);
            $file_path = $request->drug_image->store("{$company_slug}/products", "public");
            $drug->picture_path = $file_path;
        }

        $drug->name = $request->drug_name;
        $drug->slug = str_slug($drug->name);
        if ($request->drug_quantity < 1) {
            $drug->quantity = 1;
        } else {
            $drug->quantity = $request->drug_quantity;
        }
        $drug->price = $request->drug_price;
        $drug->brand = $request->drug_brand;
        $drug->description = $request->drug_description;
        $drug->category_id = $request->drug_category;
        $drug->company_id = $request->pharmacy;
        $drug->save();

        Alert::success('Drug added to repositories successfully!')->flash();
        return redirect()->route('showAllDrugs');
    }

    public function edit($id)
    {
        $data['drug'] = Stock::findOrFail($id);
        $data['categories'] = Category::all();
        $data['pharmacies'] = Company::all();
        $data['title'] = "Edit {$data['drug']->name} details";

        return view('backpack::base.drugs.new', $data)->render();
    }

    public function update(Request $request, $id)
    {
        $drug = Stock::findOrFail($id);

        $company = Company::find($request->input('pharmacy'));

        if (!is_null($request->drug_image)) {
            $company_slug = str_slug($company->company_name);
            $file_path = $request->drug_image->store("{$company_slug}/products", "public");
            $drug->picture_path = $file_path;
        }

        $drug->name = $request->drug_name;
        $drug->slug = str_slug($drug->name);
        $drug->price = $request->drug_price;
        if ($request->drug_quantity < 1) {
            $drug->quantity = 1;
        } else {
            $drug->quantity = $request->drug_quantity;
        }
        $drug->company_id = $request->pharmacy;
        $drug->category_id = $request->drug_category;
        $drug->description = $request->drug_description;
        if ($drug->save()) {
            Alert::success('Drug updated success!')->flash();
            return redirect()->route('showAllDrugs');
        } else {
            Alert::warning('Unable to update due to an error!')->flash();
            return back();
        }
    }

    public function delete($id)
    {
        Stock::findOrFail($id)->delete();
        Alert::info('Drug deleted!')->flash();
        return back();
    }
}
