<?php

namespace App\Http\Controllers\Admin;

use App\Company;
use App\Deliverytime;
use App\Http\Controllers\Controller;
use App\Role;
use App\User;
use Illuminate\Http\Request;
use Prologue\Alerts\Facades\Alert;

class UsersController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('role:admin');
    }

    public function showAllPatients()
    {
        $data['patients'] = Role::where('name', 'user')->first()->users()->paginate(30);
        $data['title'] = "Patients";
        return view('backpack::base.users.patients.index', $data)->render();
    }

    public function verifyUserAccount($id)
    {
        $user = User::findOrFail($id);
        $user->verified_by_admin = 1;
        $user->update();
        return back();
    }

    public function deactivateUserAccount($id)
    {
        $user = User::findOrFail($id);
        $user->verified_by_admin = 0;
        $user->update();
        return back();
    }

    public function deleteUser($id)
    {
        $user = User::findOrFail($id);
        $user->delete();
        Alert::success('User Deleted!')->flash();
        return back();
    }

    public function showAllPharmacists()
    {
        $data['pharmacists'] = Role::where('name', 'pharmacy')->first()->users()->paginate(30);
        $data['title'] = "Pharmacists";
        return view('backpack::base.users.pharmacists.index', $data)->render();
    }

    public function verifyPharmacistAccount($id)
    {
        $user = User::findOrFail($id);
        $user->verified_by_admin = 1;
        $user->update();
        return back();
    }

    public function deactivatePharmacistAccount($id)
    {
        $user = User::findOrFail($id);
        $user->verified_by_admin = 0;
        $user->update();
        return back();
    }

    public function viewPatientDetails($id)
    {
        $data['patient'] = User::findOrFail($id);
        return view('backpack::base.users.patients.details', $data);
    }

    public function viewPharmacistDetails($id)
    {
        $data['pharmacist'] = User::findOrFail($id);
        return view('backpack::base.users.pharmacists.details', $data);
    }

    public function addNewPharmacist(Request $request)
    {
        $this->validate($request, [
            'firstname' => 'required|string|max:255',
            'lastname' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'password' => 'required|string|max:255']);

        // Create a new user object
        $pharmacist = new User;
        $pharmacist->name = $request->firstname;
        $pharmacist->last_name = $request->lastname;
        $pharmacist->email = $request->email;
        $pharmacist->password = bcrypt($request->password);
        $pharmacist->role_in_company = $request->role_in_company;
        $pharmacist->save();

        $company = new Company;
        $company->company_name = $request->company_name;
        $company->street_address = $request->company_street;
        $company->city = $request->company_city;
        $company->state = $request->company_state;
        $company->delivery_info = $request->delivery_info;
        $pharmacist->company()->save($company);

        $delivery_schedule = new Deliverytime;
        $delivery_schedule->from = $request->start_delivery;
        $delivery_schedule->to = $request->end_delivery;
        $company->deliverytimes()->save($delivery_schedule);

        // Attach pharmacist role to user
        $role = Role::where('name', 'pharmacy')->first();
        $pharmacist->attachRole($role);

        Alert::success('New Pharmacist Account created!')->flash();
        return back();
    }

    public function addNewPatient(Request $request)
    {
        $this->validate($request, [
            'firstname' => 'required|string|max:255',
            'lastname' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'password' => 'required|string|max:255']);

        // Create a new user object
        $patient = new User;
        $patient->name = $request->firstname;
        $patient->last_name = $request->lastname;
        $patient->email = $request->email;
        $patient->password = bcrypt($request->password);
        $patient->save();

        // Attach patient role to user
        $role = Role::where('name', 'user')->first();
        $patient->attachRole($role);

        Alert::success('New Patient Account created!')->flash();
        return back();
    }
}
