<?php

namespace App\Http\Controllers\Auth;

use App\Company;
use App\Deliverytime;
use App\Http\Controllers\Controller;
use App\Role;
use App\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
        createRoles();
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        $validator = Validator::make($data, [
            'firstname' => 'required|string|max:255',
            // 'lastname' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6',
        ]);

        $validator->sometimes(['company_name',
            'company_street',
            'company_city',
            'company_state',
            'role_in_company',
            'start_delivery',
            'end_delivery'],
            'required|string|max:200', function($input){

            return $input->account_type === "pharmacist";
        });

        return $validator;

    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        $user = new User;
        DB::transaction(function() use($data, $user){

            $user->name = $data['firstname'];
            // $user->last_name = $data['lastname'];
            $user->email = $data['email'];
            $user->password = bcrypt($data['password']);
            $user->save();
            $role = Role::where('name', 'user')->first();
            $user->attachRole($role);
            // if ($data['account_type'] === "pharmacist"){
            //     $company = new Company;
            //     $company->company_name = $data['company_name'];
            //     $company->street_address = $data['company_street'];
            //     $company->city = $data['company_city'];
            //     $company->state = $data['company_state'];
            //     $user->company()->save($company);

            //     $delivery_schedule = new Deliverytime;
            //     $delivery_schedule->from = $data['start_delivery'];
            //     $delivery_schedule->to = $data['end_delivery'];
            //     $company->deliverytimes()->save($delivery_schedule);

            //     $role = Role::where('name', 'pharmacy')->first();
            //     $user->attachRole($role);
            // }
            // else{

            // }

        });
        return $user;
    }

    public function redirectTo(){

        if (auth()->user()->hasRole('user')){
            return 'patient';
        }
        elseif(auth()->user()->hasRole('pharmacy')){
            return 'pharmacist';
        }
        elseif(auth()->user()->hasRole('admin')){
            return 'administrator/dashboard';
        }
        else{

        }
    }
}
