<?php

namespace App\Http\Controllers;

use App\Category;
use App\Company;
use App\Coupon;
use App\Mail\CheckoutCompleted;
use App\Mail\OrderMadeOnline;
use App\Order;
use App\Orderitem;
use App\Stock;
use Gloudemans\Shoppingcart\Facades\Cart;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Prologue\Alerts\Facades\Alert;
use Unicodeveloper\Paystack\Facades\Paystack;

class CartController extends Controller
{
    protected $stock;

    const NEW_ORDER_EMAIL = 'hello@drugstore.ng';

    public function __construct(Stock $stock)
    {
        $this->stock = $stock;
    }

    public function ajaxAddItem(Request $request, Company $company)
    {
        $this->validate($request, ['product' => 'required']);
        $product = $this->stock->getById($request->product);
        $stock_company = $company->getCompanyById($product->company->id);
        $qty = $request->quantity;

        if (is_null($qty) || $qty < 1) {
            $qty = 1;
        }

        if ($qty > $product->quantity) {
            return response()->json([
                'status' => false,
                'message' => "There are only {$product->quantity} left in stock"
            ], 419);
        }
        if (count(Cart::content()) < 1) {
            $item = Cart::add($product->id, $product->name, $qty, $product->price);
        } else {
            $first_item = $this->stock->getById(Cart::content()->first()->id);

            $item = Cart::add($product->id, $product->name, $qty, $product->price, [
                'desc' => $product->description,
                'picture_path' => $product->picture_path
            ]);
        }

        return response()->json([
            'status' => 'success',
            'message' => "Item added to cart successfully",
            'total' => Cart::count(),
            'total_price' => Cart::subtotal(),
            'data' => $item
        ], 200);
    }
    public function addItem(Request $request, Company $company)
    {
        $this->validate($request, ['product' => 'required']);
        $product = $this->stock->getById($request->product);
        $stock_company = $company->getCompanyById($product->id);
        $qty = $request->quantity;
        if (is_null($qty) or $qty < 1) {
            $qty = 1;
        }
        if ($qty > $product->qty) {

            Alert::info("There are only {$product->quantity} left in stock")->flash();
            return back();

        }
        if (count(Cart::content()) < 1) {
            Cart::add($product->id, $product->name, $qty, $product->price);
        } else {
            $first_item = $this->stock->getById(Cart::content()->first()->id);
            //         if ($first_item->company->id !== $stock_company->id){

            // return response()->json([
            //     'status' => "false",
            //     'message' => "You can only add products from a single company at once"], 419);

            //         }
            Cart::add($product->id, $product->name, $qty, $product->price);
        }

        Alert::success("Item added to cart successfully")->flash();
        return back();
    }

    public function ajaxUpdateItem(Request $request)
    {
        $this->validate($request, [
            'row' => 'required']);
        $row_id = $request->row;
        $product = $this->stock->getById(Cart::get($row_id)->id);

        $qty = $request->quantity;
        if (is_null($qty) or $qty < 1) {
            $qty = 1;
        }
        if ($qty > $product->quantity) {
            return response()->json([
                'status' => false,
                'message' => "Theare are only {$product->quantity} left in stock"], 419);

        }

        $item = Cart::update($row_id, $qty);
        return response()->json([
            'status' => 'success',
            'message' => 'Item updated in cart',
            'total' => Cart::count(),
            'total_price' => Cart::subtotal(),
            'data' => $item]);
    }
    public function updateItem(Request $request)
    {
        $row_id = $request->row_id;
        $qty = $request->quantity;
        if (is_null($qty) or $qty < 1) {
            $qty = 1;
        }
        if ($qty > $product->quantity) {
            Alert::info("There are only {$product->quantity} left in stock")->flash();
            return back();
        }
        if (count(Cart::content()) < 1) {
            Cart::add($product->id, $product->name, $qty, $product->price);
        }
        Cart::update($row_id, $qty);
        Alert::success("Item updated in cart")->flash();
        return back();
    }

    public function ajaxRemoveItem(Request $request)
    {
        $row_id = $request->row;
        $item = Cart::remove($row_id);
        return response()->json([
            'status' => 'success',
            'message' => "Item removed successfully from cart",
            'total' => Cart::count(),
            'total_price' => Cart::subtotal(),
            'data' => $item]);
    }
    public function removeItem(Request $request)
    {
        $row_id = $request->row;
        Cart::remove($row_id);
        Alert::info("Item removed from cart")->flash();
        return back();
    }

    public function ajaxGetCartItems()
    {
        $items = Cart::content();
        return response()->json([
            'status' => 'success',
            'message' => "All cart items retrieved",
            'total' => Cart::count(),
            'total_price' => Cart::subtotal(),
            'data' => $items]);
    }

    public function viewCartItems()
    {
        $items = Cart::content();
        $data['items'] = $items;
        $data['title'] = "View cart";
        $data['categories'] = Category::whereHas('stocks')->get();
        return view('shoppingcart', $data);
    }

    public function checkout()
    {
        $data['items'] = Cart::content();
        $deliveryFee = null;
        $data['deliveryRates'] = [
            'Abia' => 3200, 'Abuja (FCT)' => 2600, 'Adamawa' => 3200, 'Akwa Ibom' => 3200, 'Anambra' => 3200, 'Bauchi' => 3200,
            'Bayelsa' => 3200, 'Benue' => 3200, 'Borno' => 3200, 'Cross River' => 3200, 'Delta' => 3200, 'Ebonyi' => 3200,
            'Enugu' => 3200, 'Edo' => 1500, 'Ekiti' => 1500, 'Gombe' => 3200, 'Imo' => 3200, 'Jigawa' => 3200, 'Kaduna' => 3200,
            'Kano' => 3200, 'Katsina' => 3200, 'Kebbi' => 3200, 'Kogi' => 3200, 'Kwara' => 1500, 'Lagos' => 1000, 'Nasarawa' => 3200,
            'Niger' => 3200, 'Ogun' => 1100, 'Ondo' => 1500, 'Osun' => 1500, 'Oyo' => 1500, 'Plateau' => 3200,
            'Rivers (Port Harcourt Region)' => 2600, 'Sokoto' => 3200, 'Taraba' => 3200, 'Yobe' => 3200, 'Zamfara' => 3200,
        ];
        $data['deliveryFee'] = $deliveryFee;
        $data['title'] = "Checkout Order";
        $data['categories'] = Category::whereHas('stocks')->get();
        $data['total_amount'] = Cart::subtotal();

        return view('checkout', $data);
    }

    public function applyCoupon(Request $request)
    {
        $coupon = Coupon::where('code', $request->coupon_code)->first();
        $total_amount = filter_var(Cart::subtotal(), FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);

        if ($coupon) {
            $discount = ($coupon->rate / 100) * $total_amount;
            $total_amount -= $discount;

            Alert::success('Coupon applied.')->flash();
            Session::put('total_amount', $total_amount);
            Session::put('coupon_code', $request->coupon_code);
            return redirect()->back()->withInput($request->all());
        }

        Alert::warning('The coupon you entered is incorrect')->flash();
        return redirect()->back();
    }

    /**
     * remove applied coupon code
     *
     * @return void
     */
    public function removeCoupon()
    {
        Session::forget('total_amount');
        return redirect()->back();
    }

    public function completeCheckout(Request $request)
    {
        $rules = ['payment_option' => 'required'];
        $this->validate($request, $rules);
        $newprice = Session::get('total_amount');
        if (Cart::content()->count() > 0) {
            DB::beginTransaction();
            $company = Stock::findOrFail((Cart::content()->first()->id))->company;
            $order = new Order;
            $order->id = random_int(000000000, 999999999);
            $order->user_id = auth()->id();
            $order->user_name = $request->input('name', auth()->user()->name);
            $order->address = $request->input('address', auth()->user()->address);
            $order->email = $request->input('email', auth()->user()->email);
            $order->user_phone = $request->input('phone', auth()->user()->phone);
            $order->company_id = $company->id;
            $order->payment_mode = $request->payment_option;
            $deliveryFee = $request->input('deliveryPrice');
            $order->total_price = (!is_null($newprice) ? (float) $newprice : (float) Cart::subtotal()) + (float) $deliveryFee;

            $order->save();

            foreach (Cart::content() as $item) {
                $order_item = new Orderitem;
                $order_item->name = $item->name;
                $order_item->quantity = $item->qty;
                $order_item->unit_price = $item->price;
                $order_item->order_id = $order->id;
                $order_item->save();
            }

            DB::commit();

            if ($request->payment_option === "pay_online") {
                $request->email = auth()->user()->email;
                $request->amount = $order->total_price * 100;
                $request->callback_url = route('confirm_paystack');
                $request->metadata = json_encode(array('custom_fields' => ['order_id' => $order->id]));
                return Paystack::getAuthorizationUrl()->redirectNow();
                Mail::to(self::NEW_ORDER_EMAIL)->send(new OrderMadeOnline($order));
                Mail::to($order->email)->send(new CheckoutCompleted($order));
            } elseif ($request->payment_option === "pay_on_delivery") {
                Mail::to($order->email)->send(new CheckoutCompleted($order));
                Mail::to(self::NEW_ORDER_EMAIL)->send(new OrderMadeOnline($order));

                foreach (Cart::content() as $item) {
                    $stock = Stock::find($item->id);
                    $stock->quantity -= $item->qty;
                    $stock->save();
                }

                Cart::destroy();
                Session::forget('total_amount');

                Alert::success("Your order has been received. Check your mail for order details")->flash();
                return redirect('/patient/orders/' . $order->id . '/details');
            } else {
                Alert::error("You selected an invalid payment option")->flash();
                return back();
            }
            // Cart::destroy();
        } else {
            echo "There are no items in your cart to checkout";
        }

    }

    public function confirmPaymentFromPaystack(Request $request)
    {
        $payment_data = Paystack::getPaymentData();
        $order_id = ($payment_data['data']['metadata']['custom_fields']['order_id']);
        $order = Order::findOrFail($order_id);

        Mail::to(collect([$order->email, auth()->user()]))->send(new CheckoutCompleted($order));
        $order->paid = 1;
        $order->save();
        foreach (Cart::content() as $item) {
            $stock = Stock::find($item->id);
            $stock->quantity -= $item->qty;
            $stock->save();
        }
        Cart::destroy();
        Alert::success("Your order has been received. Check your mail for order details")->flash();
        return redirect('/patient/orders/' . $order_id . '/details');
    }
}
