<?php

namespace App\Http\Controllers\Pharmacy;

use App\Deliverytime;
use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Prologue\Alerts\Facades\Alert;

class AccountController extends Controller
{
	public function __construct(){
		$this->middleware('auth');
		$this->middleware('role:pharmacy');
	}

    /**
     * Show profile details
     * @return view
     */
    public function index(){
        $data['user'] = User::find(Auth::id());
        return view('pharmacist.profile.index', $data);
    }

    public function dashboard(){
    	$user = User::find(auth()->id());
    	$data['user'] = $user;
    	$data['company'] = $user->company;

    	return view('pharmacist.dashboard', $data);
    }

    public function update(Request $request){
        $this->validate($request, []);

        $user = User::find(auth()->id());
        $company = $user->company;

        $user->name = $request->firstname;
        $user->last_name = $request->lastname;
        $user->street_address = $request->street_address;
        $user->city = $request->city;
        $user->state = $request->state;
        $user->role_in_company = $request->role_in_company;

        $user->save();
        $company->company_name = $request->pharmacy_name;
        $company->street_address = $request->pharmacy_street_address;
        $company->city = $request->pharmacy_city;
        $company->state = $request->pharmacy_state;

        if (!is_null($request->profile_image)){
            // dd($request->all());
            $company_slug = str_slug($company->company_name);
            $file_path = $request->profile_image->store("{$company_slug}", "public");    
            $company->picture_path = $file_path;
        }
        $user->company()->save($company);

        if ($company->deliverytimes->count() > 0){
            $delivery_schedule = $company->deliverytimes->first();

            $delivery_schedule->from = $request->start_delivery;
            $delivery_schedule->to = $request->end_delivery;
            // $company->deliverytimes()->associate($delivery_schedule);
            // $company->save();
            $company->deliverytimes()->save($delivery_schedule);

        }
        else{
            $delivery_schedule = new Deliverytime;
            $delivery_schedule->from = $request->start_delivery;
            $delivery_schedule->to = $request->end_delivery;
            $company->deliverytimes()->save($delivery_schedule);
        }

        Alert::success('Profile Updated successfully')->flash();
        return back();
    }
}
