<?php

namespace App\Http\Controllers;

use App\Category;
use App\Company;
use App\Mail\NewContactForm;
use App\Mail\PharmacyRegistration;
use App\Role;
use App\Stock;
use App\User;
use Gloudemans\Shoppingcart\Facades\Cart;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Prologue\Alerts\Facades\Alert;

class PublicController extends Controller
{
	/**
	 * @var App\Company
	 */
	protected $company;

    /**
     * @var App\Stock
     */
    protected $stock;

	public function __construct(Company $company, Stock $stock)
    {
		$this->company = $company;
        $this->stock = $stock;
	}

    public function welcome()
    {
        createRoles();
        $data['states'] = Company::groupBy('state')->get(['state']);
        $data['cities'] = Company::groupBy('city')->get(['city']);
        $data['categories'] = Category::whereHas('stocks')->get();

        return view('storefront', $data);
    }

    public function listPharmacies(){
    	$companies = $this->company->getCompanies();
        $data['categories'] = Category::whereHas('stocks')->get();
    	$data['companies'] = $companies;
    	// $data['companies'] = $companies->each(function($company) use($companies){
    	// 	$companies->push($company);
    	// });


    	$data['title'] = "Drugstores";
    	return view('locationsearchresults', $data);
    }

    /**
     * get and show details of a pharmacy
     * @param string|integer $id (could be a slug, or id)
     * @return view
     */
    public function showPharmacy($id){
    	$company = $this->company->getCompanyBySlug($id);

    	$stocks = $company->stocks()->paginate();

    	$data['company'] = $company;
    	$data['stocks'] = $stocks;
        $data['categories'] = Category::whereHas('stocks')->get();
    	$data['title'] = ucfirst($company->company_name);
    	return view('pharmacydrugslisting', $data);
    }

    public function showStock($companyId, $id){
        // $stock = $this->stock->getById($id);
        // $stock = $this->stock->getByName($id);
        $stock = $this->stock->getBySlug($id);

        $company = $stock->company;
        $title = $stock->name . " - " . $company->company_name;
        $data = ['stock' => $stock, 'company' => $company, 'title' => $title];
        $data['categories'] = Category::whereHas('stocks')->get();
        return view('stockitemdetails', $data);
    }

    public function newAdmin() {
        return view('newAdmin');
    }

    public function addNewAdmin(Request $request) {
        $this->validate($request, [
            'password' => 'string|confirmed|max:255|min:6']);

        $user = new User;
        $user->name = $request->firstname;
        $user->last_name = $request->lastname;
        $user->email = $request->email;
        $user->password = bcrypt($request->password);
        $user->save();

        $role = Role::where('name', 'admin')->first();
        $user->attachRole($role);

        return redirect()->to('login')->with('success', 'Admin Registered Successfully!');
    }

    public function contact()
    {
        $data['title'] = "Contact Us";
        $data['categories'] = Category::whereHas('stocks')->get();
        return view('contact', $data);
    }

    public function makeContact(Request $request)
    {
        Mail::send(new NewContactForm($request));
        return redirect('/');
    }

    public function about()
    {
        $data['title'] = "About Us";
        $data['categories'] = Category::whereHas('stocks')->get();

        return view('about', $data);
    }
    
    /**
     * Terms and Conditions page.
     *
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\Foundation\Application|\Illuminate\View\View
     */
    public function termsAndConditions()
    {
        $data = [];
        $data['title'] = 'Terms and Conditions';
        $data['categories'] = Category::whereHas('stocks')->get();

        return view('terms-and-conditions', $data);
    }

    public function showCategoryStocks($slug)
    {
        $category = Category::where('slug', $slug)->first();
        
        if (! $category) {
            Alert::error('Category not found!');
            return back();
        }
        
        $stocks = $category->stocks()->paginate(20);
        $data['title'] = $category->name;
        $data['category'] = $category;
        $data['categories'] = Category::whereHas('stocks')->get();
        $data['stocks'] = $stocks;

        return view('categorystock', $data);
    }

    public function registerPharmacy()
    {
        $data['title'] = "REGISTER YOUR PHARMACY";
        $data['categories'] = Category::whereHas('stocks')->get();
        return view('register-pharmacy', $data);
    }

    public function doPharmacyRegistration(Request $request)
    {
        // $when = Carbon::now()->addMinutes(5);
        Mail::send(new PharmacyRegistration($request));
        return redirect('/');
    }

    /**
     * empty cart
     * @return void
     */
    public function emptyCart()
    {
        Cart::destroy();
    }
}
