<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Order extends Model
{
	use SoftDeletes;

	public $dates = ['deleted_at'];
	public $incrementing = false;

    public function user(){
    	return $this->belongsTo(User::class);
    }

    public function company(){
    	return $this->belongsTo(Company::class);
    }

    public function stocks(){
    	return $this->hasMany(Stock::class);
    }

    public function orderitems(){
    	return $this->hasMany(Orderitem::class);
    }

    public function isConfirmed(){
    	return $this->status === 2 ? true : false;
    }

    public function isPending(){
        return $this->status === 1;
    }

    public function markComplete(){
        return $this->update(['status' => 1]);
    }

    public function getStatus(){
        if ($this->status === 1){
            return 'pending';
        }
        if ($this->status === 2){
            return 'completed';
        }
        if ($this->status === 0){
            return 'canceled';
        }
    }

    /**
     * Return the payment of an order
     * @return string
     */
    public function getPaymentStatus(){
        if ($this->paid === 0){
            return "Unpaid";
        }
        else{
            return "Paid";
        }
    }

    public function getById($id){
        return $this->where('id', $id)->firstOrFail();
    }

    public function formatPaymentMethod(){
        if ($this->payment_mode === "pay_online"){
            return "PAY ONLINE";
        }
        elseif ($this->payment_mode === "pay_on_delivery") {
            return "PAY ON DELIVERY";
        }
        else{
            return $this->payment_mode;
        }
    }
}
